------------------------------------------------------------------------
--     S3demo.vhd -- Demonstrate basic Pegasus function
------------------------------------------------------------------------
-- Author:  Clint Cole
--          Copyright 2004 Digilent, Inc.
------------------------------------------------------------------------
-- This module tests basic device function and connectivity on the Pegasus
-- board. It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		mclk		- system clock (50Mhz Oscillator on Pegasus board)
--		bn			- buttons on the Pegasus board
--		swt		- switches on the Pegasus board (8 switches)
--
--  Outputs:
--		led		- discrete LEDs on the Pegasus board (8 leds)
--		an			- anode lines for the 7-seg displays on Pegasus
--		ssg		- cathodes (segment lines) for the displays on Pegasus
--
--  VGA Components:
--		hs			- horizontal monitor sync
--		vs			- vertical monitor sync
--		red		- red pixel color
--		green		- green pixel color
--		blue		- blue pixel color
--
--	 Keyboard Components:
--		kd			- keyboard data in
--		kc			- keyboard clock in
--
------------------------------------------------------------------------
-- Revision History:
--  01/15/2004(ClintC): created
--  07/07/2004(BarronB): Added, VGA, and Keyboard Input
--  07/12/2004(BarronB): Modified for Spartan 3
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity S3demo is
    Port (
        mclk    : in std_logic;
        btn     : in std_logic_vector(3 downto 0);
        swt     : in std_logic_vector(7 downto 0);
        led     : out std_logic_vector(7 downto 0);
        an      : out std_logic_vector(3 downto 0);
        ssg     : out std_logic_vector(7 downto 0);
	hs	      : out std_logic;
	vs	      : out std_logic;
	red, grn, blu : out std_logic;
	kd, kc	      : in std_logic);
end S3demo;
										
architecture Behavioral of S3demo is

	------------------------------------------------------------------------
	-- Component Declarations       -- PUT YOURS HERE!
	------------------------------------------------------------------------

	------------------------------------------------------------------------
	-- Signal Declarations
	------------------------------------------------------------------------

	signal rst		: std_logic;  -- reset is useful
	------------------------------------------------------------------------
	-- Module Implementation
	------------------------------------------------------------------------

	begin

          -- synthesis was mad, when these were not set.
          red <= '0'; grn <= '0'; blu <= '0'; hs <= '0'; vs <= '0';
          -- set reset to a button.
          rst <= btn(1);
          -- keep track of whether switches are on or off.
          led <= swt;

          -- add your remaining instances and code below here  --


          
end Behavioral;

